from datetime import date

def get_holidays(year: int) -> list:
    """ Retourne la liste des jours fériés officiels à Madagascar pour une année donnée """
    
    holidays = [
        (date(year, 1, 1), "Jour de l'an"),
        (date(year, 3, 29), "Commémoration de l'insurrection de 1947"),
        (date(year, 5, 1), "Fête du travail"),
        (date(year, 6, 26), "Fête de l'indépendance"),
        (date(year, 8, 15), "Assomption"),
        (date(year, 11, 1), "Toussain"),
        (date(year, 12, 25), "Fête de Noël"),
    ]
    return holidays




from mada_holidays import core


def test_get_holidays():
    holidays = core.get_holidays(2025)
    assert any("Fête de l'indépendance" in label for _, label in holidays)
    assert len(holidays) >= 7


from setuptools import setup, find_packages

setup(
    name='mada_holidays',
    version='1.0',
    packages=find_packages(),
    description='Un package qui montre tous les jours fériés à Madagascar',
    author='TOTOZAFY Johnathon Wesley',
    author_email='hei.johnathon.2@gmail.com',
    url='https://github.com/Johnathon47/mada_holidays',
    python_requires='>=3.6',
    install_requires=[],
)